@@ -2,10 +2,11 @@ package Test::Simple;
 
 require 5.005;
 
-$Test::Simple::VERSION = '0.03';
+$Test::Simple::VERSION = '0.04';
 
 my(@Test_Results) = ();
 my($Num_Tests, $Planned_Tests, $Test_Died) = (0,0,0);
+my($Import_Run) = 0;
 
 # I'd like to have Test::Simple interfere with the program being
 # tested as little as possible.  This includes using Exporter or
@@ -13,6 +14,8 @@ my($Num_Tests, $Planned_Tests, $Test_Died) = (0,0,0);
 sub import {
     my($class, %config) = @_;
 
+    $Import_Run = 1;
+
     if( !exists $config{tests} ) {
         die "You have to tell $class how many tests you plan to run.\n".
             "  use $class tests => 42;  for example.\n";
@@ -223,6 +226,10 @@ $SIG{__DIE__} = sub {
 END {
     _sanity_check();
 
+    # Bailout if import() was never called.  This is so
+    # "require Test::Simple" doesn't puke.
+    exit 0 unless $Import_Run;
+
     # Figure out if we passed or failed and print helpful messages.
     if( $Num_Tests ) {
         my $num_failed = grep !$_, @Test_Results[0..$Planned_Tests-1];
